@@ -50,6 +50,7 @@ struct _CcColorCalibratePrivate
   GnomeRROutput   *output;
   GnomeRRScreen   *x11_screen;
   GtkBuilder      *builder;
+  GtkWindow       *window;
   GtkWidget       *sample_widget;
   guint            gamma_size;
   CdProfileQuality quality;
@@ -1036,6 +1037,8 @@ cc_color_calibrate_finalize (GObject *object)
   CcColorCalibrate *calibrate = CC_COLOR_CALIBRATE (object);
   CcColorCalibratePrivate *priv = calibrate->priv;
 
+  g_clear_pointer (&priv->window, gtk_widget_destroy);
+  g_clear_object (&priv->builder);
   g_clear_object (&priv->device);
   g_clear_object (&priv->proxy_helper);
   g_clear_object (&priv->proxy_inhibit);
@@ -1069,7 +1072,6 @@ cc_color_calibrate_init (CcColorCalibrate *calibrate)
 
   calibrate->priv = priv = CC_COLOR_CALIBRATE_GET_PRIVATE (calibrate);
   calibrate->priv->loop = g_main_loop_new (NULL, FALSE);
-  calibrate->priv->sample_widget = cd_sample_widget_new ();
   calibrate->priv->inhibit_fd = -1;
 
   /* load UI */
@@ -1134,6 +1136,7 @@ cc_color_calibrate_init (CcColorCalibrate *calibrate)
   cc_color_calibrate_alpha_screen_changed_cb (GTK_WINDOW (window), NULL, calibrate);
   g_signal_connect (window, "screen-changed",
                     G_CALLBACK (cc_color_calibrate_alpha_screen_changed_cb), calibrate);
+  priv->window = window;
 }
 
 CcColorCalibrate *
