@@ -60,6 +60,7 @@ struct _CcColorPanelPrivate
   GtkListBox    *list_box;
   gchar         *list_box_filter;
   guint          list_box_selected_id;
+  guint          list_box_activated_id;
   GtkSizeGroup  *list_box_size;
   gboolean       is_live_cd;
   gboolean       model_is_changing;
@@ -608,6 +609,7 @@ gcm_prefs_title_entry_changed_cb (GtkWidget *widget,
   page = GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder,
                                              "box_calib_title"));
   value = gtk_entry_get_text (GTK_ENTRY (widget));
+  cc_color_calibrate_set_title (prefs->priv->calibrate, value);
   gtk_assistant_set_page_complete (assistant, page, value[0] != '\0');
 }
 
@@ -2001,6 +2003,17 @@ gcm_prefs_refresh_toolbar_buttons (CcColorPanel *panel)
   gtk_widget_set_visible (widget, !is_device);
 }
 
+static void
+gcm_prefs_list_box_row_activated_cb (GtkListBox *list_box,
+                                     GtkListBoxRow *row,
+                                     CcColorPanel *prefs)
+{
+  if (CC_IS_COLOR_PROFILE (row))
+    {
+      gcm_prefs_device_profile_enable_cb (NULL, prefs);
+    }
+}
+
 static void
 gcm_prefs_connect_cb (GObject *object,
                       GAsyncResult *res,
@@ -2114,6 +2127,11 @@ cc_color_panel_dispose (GObject *object)
       g_signal_handler_disconnect (priv->list_box,
                                    priv->list_box_selected_id);
       priv->list_box_selected_id = 0;
+
+      /* row-activated event should be connected at this point */
+      g_signal_handler_disconnect (priv->list_box,
+                                   priv->list_box_activated_id);
+      priv->list_box_activated_id = 0;
     }
 
   /* stop the devices from emitting after the ListBox has been disposed */
@@ -2258,6 +2276,7 @@ cc_color_panel_init (CcColorPanel *prefs)
 
   /* can do native display calibration using colord-session */
   priv->calibrate = cc_color_calibrate_new ();
+  cc_color_calibrate_set_quality (priv->calibrate, CD_PROFILE_QUALITY_MEDIUM);
 
   /* setup defaults */
   priv->settings = g_settings_new (GCM_SETTINGS_SCHEMA);
@@ -2499,10 +2518,15 @@ cc_color_panel_init (CcColorPanel *prefs)
                                 prefs, NULL);
   gtk_list_box_set_selection_mode (priv->list_box,
                                    GTK_SELECTION_SINGLE);
+  gtk_list_box_set_activate_on_single_click (priv->list_box, FALSE);
   priv->list_box_selected_id =
     g_signal_connect (priv->list_box, "row-selected",
                       G_CALLBACK (gcm_prefs_list_box_row_selected_cb),
                       prefs);
+  priv->list_box_activated_id =
+    g_signal_connect (priv->list_box, "row-activated",
+                    G_CALLBACK (gcm_prefs_list_box_row_activated_cb),
+                    prefs);
   priv->list_box_size = gtk_size_group_new (GTK_SIZE_GROUP_VERTICAL);
 
   widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "scrolledwindow_devices"));
