@@ -399,6 +399,8 @@ GResource *cc_common_get_resource (void)
 
 */
 
+#ifndef __GTK_DOC_IGNORE__
+
 #if  __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 7)
 
 #define G_HAS_CONSTRUCTORS 1
@@ -472,6 +474,7 @@ GResource *cc_common_get_resource (void)
 
 #endif
 
+#endif /* __GTK_DOC_IGNORE__ */
 
 #ifdef G_HAS_CONSTRUCTORS
 
