@@ -87,6 +87,10 @@ struct _CcDisplayPanelPrivate
 
   GDBusProxy *shell_proxy;
   GCancellable *shell_cancellable;
+
+  guint       sensor_watch_id;
+  GDBusProxy *iio_sensor_proxy;
+  gboolean    has_accelerometer;
 };
 
 typedef struct
@@ -189,6 +193,14 @@ cc_display_panel_dispose (GObject *object)
   CcShell *shell;
   GtkWidget *toplevel;
 
+  if (priv->sensor_watch_id > 0)
+    {
+      g_bus_unwatch_name (priv->sensor_watch_id);
+      priv->sensor_watch_id = 0;
+    }
+
+  g_clear_object (&priv->iio_sensor_proxy);
+
   if (output_ids)
     {
       g_hash_table_destroy (output_ids);
@@ -263,6 +275,37 @@ should_show_resolution (gint output_width,
   return FALSE;
 }
 
+static void
+apply_rotation_to_geometry (GnomeRROutputInfo *output, int *w, int *h)
+{
+  GnomeRRRotation rotation;
+
+  rotation = gnome_rr_output_info_get_rotation (output);
+  if ((rotation & GNOME_RR_ROTATION_90) || (rotation & GNOME_RR_ROTATION_270))
+    {
+      int tmp;
+      tmp = *h;
+      *h = *w;
+      *w = tmp;
+    }
+}
+
+static void
+get_geometry (GnomeRROutputInfo *output, int *x, int *y, int *w, int *h)
+{
+  if (gnome_rr_output_info_is_active (output))
+    {
+      gnome_rr_output_info_get_geometry (output, x, y, w, h);
+    }
+  else
+    {
+      gnome_rr_output_info_get_geometry (output, x, y, NULL, NULL);
+      *h = gnome_rr_output_info_get_preferred_height (output);
+      *w = gnome_rr_output_info_get_preferred_width (output);
+    }
+
+  apply_rotation_to_geometry (output, w, h);
+}
 
 static void
 on_viewport_changed (FooScrollArea *scroll_area,
@@ -285,34 +328,13 @@ paint_output (CcDisplayPanel    *panel,
               gint               allocated_width,
               gint               allocated_height)
 {
-  GnomeRRRotation rotation;
   GdkPixbuf *pixbuf;
   gint x, y, width, height;
-  gboolean active;
 
-  active = gnome_rr_output_info_is_active (output);
-  if (active)
-    gnome_rr_output_info_get_geometry (output, NULL, NULL, &width, &height);
-  else
-    {
-      width = gnome_rr_output_info_get_preferred_width (output);
-      height = gnome_rr_output_info_get_preferred_height (output);
-    }
-
-  rotation = gnome_rr_output_info_get_rotation (output);
+  get_geometry (output, NULL, NULL, &width, &height);
 
   x = y = 0;
 
-  if ((rotation & GNOME_RR_ROTATION_90) || (rotation & GNOME_RR_ROTATION_270))
-    {
-      gint tmp;
-
-      /* swap width and height */
-      tmp = width;
-      width = height;
-      height = tmp;
-    }
-
   /* scale to fit allocation */
   if (width / (double) height < allocated_width / (double) allocated_height)
     {
@@ -430,17 +452,9 @@ display_preview_new (CcDisplayPanel    *panel,
                      gint               base_height)
 {
   GtkWidget *area;
-  gint width, height, x, y;
-  gboolean active;
+  gint width, height;
 
-  active = gnome_rr_output_info_is_active (output);
-  if (active)
-    gnome_rr_output_info_get_geometry (output, &x, &y, &width, &height);
-  else
-    {
-      width = gnome_rr_output_info_get_preferred_width (output);
-      height = gnome_rr_output_info_get_preferred_height (output);
-    }
+  get_geometry (output, NULL, NULL, &width, &height);
 
   area = gtk_drawing_area_new ();
   g_signal_connect (area, "draw", G_CALLBACK (display_preview_draw), panel);
@@ -495,6 +509,9 @@ on_screen_changed (CcDisplayPanel *panel)
     {
       GnomeRROutput *output;
 
+      if (!gnome_rr_output_info_is_primary_tile (outputs[i]))
+	continue;
+
       output = gnome_rr_screen_get_output_by_name (priv->screen,
                                                    gnome_rr_output_info_get_name (outputs[i]));
 
@@ -516,7 +533,6 @@ on_screen_changed (CcDisplayPanel *panel)
     {
       GtkWidget *row, *item, *preview, *label;
       gboolean primary, active;
-      gint x, y, width, height;
       const gchar *status;
       gboolean display_closed = FALSE;
       GnomeRROutput *output;
@@ -534,16 +550,6 @@ on_screen_changed (CcDisplayPanel *panel)
       item = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
       gtk_container_set_border_width (GTK_CONTAINER (item), 12);
 
-      active = gnome_rr_output_info_is_active (output_info);
-
-      gnome_rr_output_info_get_geometry (output_info, &x, &y, &width, &height);
-
-      if (!active)
-        {
-          width = gnome_rr_output_info_get_preferred_width (output_info);
-          height = gnome_rr_output_info_get_preferred_height (output_info);
-        }
-
       preview = display_preview_new (panel, output_info, current, ++number,
                                      DISPLAY_PREVIEW_LIST_HEIGHT);
       gtk_size_group_add_widget (sizegroup, preview);
@@ -600,20 +606,6 @@ on_screen_changed (CcDisplayPanel *panel)
   ensure_monitor_labels (panel);
 }
 
-static void
-apply_rotation_to_geometry (GnomeRROutputInfo *output, int *w, int *h)
-{
-  GnomeRRRotation rotation;
-
-  rotation = gnome_rr_output_info_get_rotation (output);
-  if ((rotation & GNOME_RR_ROTATION_90) || (rotation & GNOME_RR_ROTATION_270))
-    {
-      int tmp;
-      tmp = *h;
-      *h = *w;
-      *w = tmp;
-    }
-}
 
 static void
 realign_outputs_after_resolution_change (CcDisplayPanel *self, GnomeRROutputInfo *output_that_changed, int old_width, int old_height, GnomeRRRotation old_rotation)
@@ -671,6 +663,9 @@ realign_outputs_after_resolution_change (CcDisplayPanel *self, GnomeRROutputInfo
       if (outputs[i] == output_that_changed || !gnome_rr_output_info_is_connected (outputs[i]))
         continue;
 
+      if (!gnome_rr_output_info_is_primary_tile (outputs[i]))
+	continue;
+
       gnome_rr_output_info_get_geometry (outputs[i], &output_x, &output_y, &output_width, &output_height);
 
       if (output_x >= old_right_edge)
@@ -731,21 +726,7 @@ lay_out_outputs_horizontally (CcDisplayPanel *self)
 
 }
 
-static void
-get_geometry (GnomeRROutputInfo *output, int *w, int *h)
-{
-  if (gnome_rr_output_info_is_active (output))
-    {
-      gnome_rr_output_info_get_geometry (output, NULL, NULL, w, h);
-    }
-  else
-    {
-      *h = gnome_rr_output_info_get_preferred_height (output);
-      *w = gnome_rr_output_info_get_preferred_width (output);
-    }
 
-  apply_rotation_to_geometry (output, w, h);
-}
 
 #define SPACE 15
 #define MARGIN  15
@@ -768,13 +749,16 @@ list_connected_outputs (CcDisplayPanel *self, int *total_w, int *total_h)
   outputs = gnome_rr_config_get_outputs (self->priv->current_configuration);
   for (i = 0; outputs[i] != NULL; ++i)
     {
+      if (!gnome_rr_output_info_is_primary_tile (outputs[i]))
+	continue;
+
       if (gnome_rr_output_info_is_connected (outputs[i]))
 	{
 	  int w, h;
 
 	  result = g_list_prepend (result, outputs[i]);
 
-	  get_geometry (outputs[i], &w, &h);
+	  get_geometry (outputs[i], NULL, NULL, &w, &h);
 
           *total_w += w;
           *total_h += h;
@@ -851,15 +835,7 @@ list_edges_for_output (GnomeRROutputInfo *output, GArray *edges)
 {
   int x, y, w, h;
 
-  gnome_rr_output_info_get_geometry (output, &x, &y, &w, &h);
-
-  if (!gnome_rr_output_info_is_active (output))
-    {
-      h = gnome_rr_output_info_get_preferred_height (output);
-      w = gnome_rr_output_info_get_preferred_width (output);
-    }
-
-  apply_rotation_to_geometry (output, &w, &h);
+  get_geometry (output, &x, &y, &w, &h);
 
   /* Top, Bottom, Left, Right */
   add_edge (output, x, y, x + w, y, edges);
@@ -877,7 +853,11 @@ list_edges (GnomeRRConfig *config, GArray *edges)
   for (i = 0; outputs[i]; ++i)
     {
       if (gnome_rr_output_info_is_connected (outputs[i]))
-	list_edges_for_output (outputs[i], edges);
+	{
+	  if (!gnome_rr_output_info_is_primary_tile (outputs[i]))
+	    continue;
+	  list_edges_for_output (outputs[i], edges);
+	}
     }
 }
 
@@ -1057,15 +1037,7 @@ output_is_aligned (GnomeRROutputInfo *output, GArray *edges)
 static void
 get_output_rect (GnomeRROutputInfo *output, GdkRectangle *rect)
 {
-  gnome_rr_output_info_get_geometry (output, &rect->x, &rect->y, &rect->width, &rect->height);
-
-  if (!gnome_rr_output_info_is_active (output))
-    {
-      rect->width = gnome_rr_output_info_get_preferred_width (output);
-      rect->height = gnome_rr_output_info_get_preferred_height (output);
-    }
-
-  apply_rotation_to_geometry (output, &rect->width, &rect->height);
+  get_geometry (output, &rect->x, &rect->y, &rect->width, &rect->height);
 }
 
 static gboolean
@@ -1082,6 +1054,8 @@ output_overlaps (GnomeRROutputInfo *output, GnomeRRConfig *config)
   outputs = gnome_rr_config_get_outputs (config);
   for (i = 0; outputs[i]; ++i)
     {
+      if (!gnome_rr_output_info_is_primary_tile (outputs[i]))
+	continue;
       if (outputs[i] != output && gnome_rr_output_info_is_connected (outputs[i]))
 	{
 	  GdkRectangle other_rect;
@@ -1105,6 +1079,8 @@ gnome_rr_config_is_aligned (GnomeRRConfig *config, GArray *edges)
   outputs = gnome_rr_config_get_outputs (config);
   for (i = 0; outputs[i]; ++i)
     {
+      if (!gnome_rr_output_info_is_primary_tile (outputs[i]))
+	continue;
       if (gnome_rr_output_info_is_connected (outputs[i]))
 	{
 	  if (!output_is_aligned (outputs[i], edges))
@@ -1455,12 +1431,11 @@ on_area_paint (FooScrollArea  *area,
       g_list_free (connected_outputs);
 
       foo_scroll_area_get_viewport (area, &viewport);
-      get_geometry (output, &w, &h);
+      get_geometry (output, &output_x, &output_y, &w, &h);
 
       viewport.height -= 2 * MARGIN;
       viewport.width -= 2 * MARGIN;
 
-      gnome_rr_output_info_get_geometry (output, &output_x, &output_y, NULL, NULL);
       x = output_x * scale + MARGIN + (viewport.width - total_w * scale) / 2.0;
       y = output_y * scale + MARGIN + (viewport.height - total_h * scale) / 2.0;
 
@@ -1471,8 +1446,8 @@ on_area_paint (FooScrollArea  *area,
       cairo_fill (cr);
 
       cairo_translate (cr, x, y);
-      paint_output (self, cr, self->priv->current_configuration, list->data,
-                    cc_display_panel_get_output_id (list->data),
+      paint_output (self, cr, self->priv->current_configuration, output,
+                    cc_display_panel_get_output_id (output),
                     w * scale, h * scale);
 
       cairo_restore (cr);
@@ -1495,6 +1470,10 @@ compute_virtual_size_for_configuration (GnomeRRConfig *config, int *ret_width, i
   outputs = gnome_rr_config_get_outputs (config);
   for (i = 0; outputs[i] != NULL; i++)
     {
+
+      if (!gnome_rr_output_info_is_primary_tile (outputs[i]))
+	continue;
+
       if (gnome_rr_output_info_is_active (outputs[i]))
 	{
 	  gnome_rr_output_info_get_geometry (outputs[i], &output_x, &output_y, &output_width, &output_height);
@@ -1987,6 +1966,30 @@ sanity_check_rotation (GnomeRROutputInfo *output)
   gnome_rr_output_info_set_rotation (output, rotation);
 }
 
+static gboolean
+should_show_rotation (CcDisplayPanel *panel,
+                      GnomeRROutput  *output)
+{
+  CcDisplayPanelPrivate *priv = panel->priv;
+  gboolean supports_rotation;
+
+  supports_rotation = gnome_rr_output_info_supports_rotation (priv->current_output,
+                                                              GNOME_RR_ROTATION_90 |
+                                                              GNOME_RR_ROTATION_180 |
+                                                              GNOME_RR_ROTATION_270);
+
+  /* Doesn't support rotation at all */
+  if (!supports_rotation)
+    return FALSE;
+
+  /* We can always rotate displays that aren't builtin */
+  if (!gnome_rr_output_is_builtin_display (output))
+    return TRUE;
+
+  /* Only offer rotation if there's no accelerometer */
+  return !priv->has_accelerometer;
+}
+
 static void
 show_setup_dialog (CcDisplayPanel *panel)
 {
@@ -2051,10 +2054,7 @@ show_setup_dialog (CcDisplayPanel *panel)
   gtk_grid_attach (GTK_GRID (priv->config_grid), preview, 0, 0, 2, 1);
 
   /* rotation */
-  show_rotation = gnome_rr_output_info_supports_rotation (priv->current_output,
-                                                          GNOME_RR_ROTATION_90 |
-                                                          GNOME_RR_ROTATION_180 |
-                                                          GNOME_RR_ROTATION_270);
+  show_rotation = should_show_rotation (panel, output);
   rotation = gnome_rr_output_info_get_rotation (priv->current_output);
 
   if (show_rotation)
@@ -2312,8 +2312,6 @@ show_setup_dialog (CcDisplayPanel *panel)
                    * output is no longer primary */
 
                   gnome_rr_output_info_set_primary (outputs[i], !primary);
-                  if (!was_primary)
-                    break;
                 }
             }
 
@@ -2424,6 +2422,84 @@ shell_proxy_ready (GObject        *source,
   ensure_monitor_labels (self);
 }
 
+static void
+update_has_accel (CcDisplayPanel *self)
+{
+  GVariant *v;
+
+  if (self->priv->iio_sensor_proxy == NULL)
+    {
+      g_debug ("Has no accelerometer");
+      self->priv->has_accelerometer = FALSE;
+      return;
+    }
+
+  v = g_dbus_proxy_get_cached_property (self->priv->iio_sensor_proxy, "HasAccelerometer");
+  if (v)
+    {
+      self->priv->has_accelerometer = g_variant_get_boolean (v);
+      g_variant_unref (v);
+    }
+  else
+    {
+      self->priv->has_accelerometer = FALSE;
+    }
+
+  g_debug ("Has %saccelerometer", self->priv->has_accelerometer ? "" : "no ");
+}
+
+static void
+sensor_proxy_properties_changed_cb (GDBusProxy     *proxy,
+                                    GVariant       *changed_properties,
+                                    GStrv           invalidated_properties,
+                                    CcDisplayPanel *self)
+{
+  GVariantDict dict;
+
+  g_variant_dict_init (&dict, changed_properties);
+
+  if (g_variant_dict_contains (&dict, "HasAccelerometer"))
+    update_has_accel (self);
+}
+
+static void
+sensor_proxy_appeared_cb (GDBusConnection *connection,
+                          const gchar     *name,
+                          const gchar     *name_owner,
+                          gpointer         user_data)
+{
+  CcDisplayPanel *self = user_data;
+
+  g_debug ("SensorProxy appeared");
+
+  self->priv->iio_sensor_proxy = g_dbus_proxy_new_sync (connection,
+                                                        G_DBUS_PROXY_FLAGS_NONE,
+                                                        NULL,
+                                                        "net.hadess.SensorProxy",
+                                                        "/net/hadess/SensorProxy",
+                                                        "net.hadess.SensorProxy",
+                                                        NULL,
+                                                        NULL);
+  g_return_if_fail (self->priv->iio_sensor_proxy);
+
+  g_signal_connect (self->priv->iio_sensor_proxy, "g-properties-changed",
+                    G_CALLBACK (sensor_proxy_properties_changed_cb), self);
+  update_has_accel (self);
+}
+
+static void
+sensor_proxy_vanished_cb (GDBusConnection *connection,
+                          const gchar     *name,
+                          gpointer         user_data)
+{
+  CcDisplayPanel *self = user_data;
+
+  g_debug ("SensorProxy vanished");
+
+  g_clear_object (&self->priv->iio_sensor_proxy);
+  update_has_accel (self);
+}
+
 static void
 cc_display_panel_init (CcDisplayPanel *self)
 {
@@ -2521,4 +2597,12 @@ cc_display_panel_init (CcDisplayPanel *self)
                             self->priv->shell_cancellable,
                             (GAsyncReadyCallback) shell_proxy_ready,
                             self);
+
+  priv->sensor_watch_id = g_bus_watch_name (G_BUS_TYPE_SYSTEM,
+                                            "net.hadess.SensorProxy",
+                                            G_BUS_NAME_WATCHER_FLAGS_NONE,
+                                            sensor_proxy_appeared_cb,
+                                            sensor_proxy_vanished_cb,
+                                            self,
+                                            NULL);
 }
