@@ -215,7 +215,6 @@ net_proxy_add_to_notebook (NetObject *object,
                            GtkSizeGroup *heading_size_group)
 {
         GtkWidget *widget;
-        GtkWindow *window;
         NetProxy *proxy = NET_PROXY (object);
 
         /* add widgets to size group */
@@ -223,15 +222,9 @@ net_proxy_add_to_notebook (NetObject *object,
                                                      "heading_proxy_method"));
         gtk_size_group_add_widget (heading_size_group, widget);
 
-        /* reparent */
-        window = GTK_WINDOW (gtk_builder_get_object (proxy->priv->builder,
-                                                     "window_tmp"));
         widget = GTK_WIDGET (gtk_builder_get_object (proxy->priv->builder,
                                                      "grid5"));
-        g_object_ref (widget);
-        gtk_container_remove (GTK_CONTAINER (window), widget);
         gtk_notebook_append_page (notebook, widget, NULL);
-        g_object_unref (widget);
         return widget;
 }
 
