@@ -981,11 +981,14 @@ als_enabled_state_changed (CcPowerPanel *self)
   gboolean visible = FALSE;
   GVariant *v;
 
-  v = g_dbus_proxy_get_cached_property (self->priv->screen_proxy, "Brightness");
-  if (v != NULL)
+  if (priv->screen_proxy != NULL)
     {
-      has_brightness = g_variant_get_int32 (v) >= 0.0;
-      g_variant_unref (v);
+      v = g_dbus_proxy_get_cached_property (priv->screen_proxy, "Brightness");
+      if (v != NULL)
+        {
+          has_brightness = g_variant_get_int32 (v) >= 0.0;
+          g_variant_unref (v);
+        }
     }
 
   if (priv->iio_proxy != NULL)
@@ -1036,6 +1039,7 @@ got_screen_proxy_cb (GObject *source_object, GAsyncResult *res, gpointer user_da
                     G_CALLBACK (on_screen_property_change), self);
 
   sync_screen_brightness (self);
+  als_enabled_state_changed (self);
 }
 
 static void
@@ -1506,6 +1510,8 @@ iio_proxy_appeared_cb (GDBusConnection *connection,
                        gpointer user_data)
 {
   CcPowerPanel *self = CC_POWER_PANEL (user_data);
+  GError *error = NULL;
+
   self->priv->iio_proxy =
     g_dbus_proxy_new_for_bus_sync (G_BUS_TYPE_SYSTEM,
                                    G_DBUS_PROXY_FLAGS_NONE,
@@ -1513,7 +1519,14 @@ iio_proxy_appeared_cb (GDBusConnection *connection,
                                    "net.hadess.SensorProxy",
                                    "/net/hadess/SensorProxy",
                                    "net.hadess.SensorProxy",
-                                   NULL, NULL);
+                                   NULL, &error);
+  if (error != NULL)
+    {
+      g_warning ("Could not create IIO sensor proxy: %s", error->message);
+      g_error_free (error);
+      return;
+    }
+
   g_signal_connect_swapped (G_OBJECT (self->priv->iio_proxy), "g-properties-changed",
                             G_CALLBACK (als_enabled_state_changed), self);
   als_enabled_state_changed (self);
