@@ -4,7 +4,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3 of the License, or
+ * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  * Author: Marek Kasik <mkasik@redhat.com>
  */
@@ -23,13 +22,12 @@
 #define __PP_JOBS_DIALOG_H__
 
 #include <gtk/gtk.h>
+#include "pp-utils.h"
 
 G_BEGIN_DECLS
 
 typedef struct _PpJobsDialog PpJobsDialog;
 
-typedef void (*UserResponseCallback) (GtkDialog *dialog, gint response_id, gpointer user_data);
-
 PpJobsDialog *pp_jobs_dialog_new    (GtkWindow            *parent,
                                      UserResponseCallback  user_callback,
                                      gpointer              user_data,
