@@ -350,7 +350,8 @@ ipp_option_add (IPPAttribute *attr_supported,
       label = gtk_label_new (option_display_name);
       context = gtk_widget_get_style_context (label);
       gtk_style_context_add_class (context, "dim-label");
-      gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
+      gtk_widget_set_halign (label, GTK_ALIGN_END);
+      gtk_widget_set_valign (label, GTK_ALIGN_CENTER);
       gtk_widget_set_margin_start (label, 10);
       gtk_grid_attach (GTK_GRID (grid), label, 0, position, 1, 1);
 
@@ -381,7 +382,8 @@ ppd_option_add (ppd_option_t  option,
       label = gtk_label_new (ppd_option_name_translate (&option));
       context = gtk_widget_get_style_context (label);
       gtk_style_context_add_class (context, "dim-label");
-      gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
+      gtk_widget_set_halign (label, GTK_ALIGN_END);
+      gtk_widget_set_valign (label, GTK_ALIGN_CENTER);
       gtk_widget_set_margin_start (label, 10);
       gtk_grid_attach (GTK_GRID (grid), label, 0, position, 1, 1);
 
@@ -810,55 +812,6 @@ populate_options (PpOptionsDialog *dialog)
                             dialog);
 }
 
-/*
- * Modify padding of the content area of the GtkDialog
- * so it is aligned with the action area.
- */
-static void
-update_alignment_padding (GtkWidget     *widget,
-                          GtkAllocation *allocation,
-                          gpointer       user_data)
-{
-  PpOptionsDialog *dialog = (PpOptionsDialog*) user_data;
-  GtkAllocation    allocation1, allocation2;
-  GtkWidget       *action_area;
-  GtkWidget       *content_area;
-  gint             offset_left, offset_right;
-  guint            padding_left, padding_right,
-                   padding_top, padding_bottom;
-
-  action_area = (GtkWidget*)
-    gtk_builder_get_object (dialog->builder, "dialog-action-area1");
-  gtk_widget_get_allocation (action_area, &allocation2);
-
-  content_area = (GtkWidget*)
-    gtk_builder_get_object (dialog->builder, "content-alignment");
-  gtk_widget_get_allocation (content_area, &allocation1);
-
-  offset_left = allocation2.x - allocation1.x;
-  offset_right = (allocation1.x + allocation1.width) -
-                 (allocation2.x + allocation2.width);
-
-  gtk_alignment_get_padding  (GTK_ALIGNMENT (content_area),
-                              &padding_top, &padding_bottom,
-                              &padding_left, &padding_right);
-  if (allocation1.x >= 0 && allocation2.x >= 0)
-    {
-      if (offset_left > 0 && offset_left != padding_left)
-        gtk_alignment_set_padding (GTK_ALIGNMENT (content_area),
-                                   padding_top, padding_bottom,
-                                   offset_left, padding_right);
-
-      gtk_alignment_get_padding  (GTK_ALIGNMENT (content_area),
-                                  &padding_top, &padding_bottom,
-                                  &padding_left, &padding_right);
-      if (offset_right > 0 && offset_right != padding_right)
-        gtk_alignment_set_padding (GTK_ALIGNMENT (content_area),
-                                   padding_top, padding_bottom,
-                                   padding_left, offset_right);
-    }
-}
-
 static void
 options_dialog_response_cb (GtkDialog *_dialog,
                             gint       response_id,
@@ -924,7 +877,6 @@ pp_options_dialog_new (GtkWindow            *parent,
 
   /* connect signals */
   g_signal_connect (dialog->dialog, "response", G_CALLBACK (options_dialog_response_cb), dialog);
-  g_signal_connect (dialog->dialog, "size-allocate", G_CALLBACK (update_alignment_padding), dialog);
 
   gtk_window_set_title (GTK_WINDOW (dialog->dialog), printer_name);
 
