@@ -36,6 +36,7 @@
 
 
 typedef struct {
+        GtkWidget *done_button;
         GtkWidget *no_results;
         GtkListBoxRow *more_item;
         GtkWidget *filter_entry;
@@ -461,7 +462,33 @@ row_activated (GtkListBox  *box,
                 return;
         }
         new_locale_id = g_object_get_data (G_OBJECT (row), "locale-id");
-        set_locale_id (chooser, new_locale_id);
+        if (g_strcmp0 (new_locale_id, priv->region) == 0) {
+                gtk_dialog_response (GTK_DIALOG (chooser),
+                                     gtk_dialog_get_response_for_widget (GTK_DIALOG (chooser),
+                                                                         priv->done_button));
+        } else {
+                set_locale_id (chooser, new_locale_id);
+        }
+}
+
+static void
+activate_default (GtkWindow *window,
+                  GtkDialog *chooser)
+{
+        CcFormatChooserPrivate *priv = GET_PRIVATE (chooser);
+        GtkWidget *focus;
+        gchar *locale_id;
+
+        focus = gtk_window_get_focus (window);
+        if (!focus)
+                return;
+
+        locale_id = g_object_get_data (G_OBJECT (focus), "locale-id");
+        if (g_strcmp0 (locale_id, priv->region) == 0)
+                return;
+
+        g_signal_stop_emission_by_name (window, "activate-default");
+        gtk_widget_activate (focus);
 }
 
 static void
@@ -498,6 +525,7 @@ cc_format_chooser_new (GtkWidget *parent)
         g_object_set_data_full (G_OBJECT (chooser), "private", priv, cc_format_chooser_private_free);
         g_object_set_data_full (G_OBJECT (chooser), "builder", builder, g_object_unref);
 
+        priv->done_button = WID ("ok-button");
         priv->filter_entry = WID ("region-filter-entry");
         priv->list = WID ("region-list");
         priv->scrolledwindow = WID ("region-scrolledwindow");
@@ -538,6 +566,9 @@ cc_format_chooser_new (GtkWidget *parent)
 
         gtk_window_set_transient_for (GTK_WINDOW (chooser), GTK_WINDOW (parent));
 
+        g_signal_connect (chooser, "activate-default",
+                          G_CALLBACK (activate_default), chooser);
+
         return chooser;
 }
 
