@@ -56,25 +56,6 @@ get_widget (UmHistoryDialog *um,
         return (GtkWidget *)gtk_builder_get_object (um->builder, name);
 }
 
-static void
-close_history_dialog (GtkButton       *button,
-                      UmHistoryDialog *um)
-{
-        gtk_widget_hide (um->dialog);
-
-        um_history_dialog_set_user (um, NULL);
-
-        if (um->week) {
-                g_date_time_unref (um->week);
-                um->week = NULL;
-        }
-
-        if (um->current_week) {
-                g_date_time_unref (um->current_week);
-                um->current_week = NULL;
-        }
-}
-
 static void
 show_week_label (UmHistoryDialog *um)
 {
@@ -324,6 +305,11 @@ um_history_dialog_show (UmHistoryDialog *um,
 {
         GDateTime *temp, *local;
 
+        if (um->week)
+                g_date_time_unref (um->week);
+        if (um->current_week)
+                g_date_time_unref (um->current_week);
+
         /* Set the first day of this week */
         local = g_date_time_new_now_local ();
         temp = g_date_time_new_local (g_date_time_get_year (local),
@@ -347,13 +333,10 @@ um_history_dialog_new (void)
         GError *error = NULL;
         UmHistoryDialog *um;
         GtkWidget *widget;
-        gboolean rtl;
 
         um = g_new0 (UmHistoryDialog, 1);
         um->builder = gtk_builder_new ();
 
-        rtl = gtk_widget_get_default_direction () == GTK_TEXT_DIR_RTL;
-
         if (!gtk_builder_add_from_resource (um->builder, "/org/gnome/control-center/user-accounts/history-dialog.ui", &error)) {
                 g_error ("%s", error->message);
                 g_error_free (error);
@@ -373,12 +356,12 @@ um_history_dialog_new (void)
 
         widget = get_widget (um, "next-image");
         gtk_image_set_from_icon_name (GTK_IMAGE (widget),
-                                      rtl ? "go-next-rtl-symbolic" : "go-next-symbolic",
+                                      "go-next-symbolic",
                                       GTK_ICON_SIZE_MENU);
 
         widget = get_widget (um, "previous-image");
         gtk_image_set_from_icon_name (GTK_IMAGE (widget),
-                                      rtl ? "go-previous-rtl-symbolic" : "go-previous-symbolic",
+                                      "go-previous-symbolic",
                                       GTK_ICON_SIZE_MENU);
 
         return um;
