@@ -74,16 +74,12 @@ struct _CcPanelClass
   /*< private >*/
   GtkBinClass parent_class;
 
-  GOptionGroup * (* get_option_group) (GVariantBuilder *builder);
   GPermission * (* get_permission) (CcPanel *panel);
   const char  * (* get_help_uri)   (CcPanel *panel);
 };
 
 GType        cc_panel_get_type         (void);
 
-GOptionGroup *cc_panel_get_option_group (GType            panel_type,
-                                         GVariantBuilder *builder);
-
 CcShell*     cc_panel_get_shell        (CcPanel     *panel);
 
 GPermission *cc_panel_get_permission   (CcPanel     *panel);
